==> trilinos-15.0.0-3-x86_64.pkg.tar.zst: usr/lib/cmake/STKUtil/STKUtilTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "STKUtil::stk_util_util" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_util PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_util.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_util_util.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_util )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_util "${_IMPORT_PREFIX}/lib/libstk_util_util.so.15.0" )

# Import target "STKUtil::stk_util_parallel" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_parallel APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_parallel PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_parallel.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_util_parallel.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_parallel )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_parallel "${_IMPORT_PREFIX}/lib/libstk_util_parallel.so.15.0" )

# Import target "STKUtil::stk_util_env" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_env APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_env PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_env.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_util_env.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_env )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_env "${_IMPORT_PREFIX}/lib/libstk_util_env.so.15.0" )

# Import target "STKUtil::stk_util_registry" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_registry APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_registry PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_registry.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_util_registry.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_registry )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_registry "${_IMPORT_PREFIX}/lib/libstk_util_registry.so.15.0" )

# Import target "STKUtil::stk_util_diag" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_diag APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_diag PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_diag.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_util_diag.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_diag )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_diag "${_IMPORT_PREFIX}/lib/libstk_util_diag.so.15.0" )

# Import target "STKUtil::stk_util_command_line" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_command_line APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_command_line PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_command_line.so.15.0"
  IMPORTED_SONAME_RELEASE "libstk_util_command_line.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_command_line )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_command_line "${_IMPORT_PREFIX}/lib/libstk_util_command_line.so.15.0" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> trilinos-15.1.1-1-x86_64.pkg.tar.zst: usr/lib/cmake/STKUtil/STKUtilTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "STKUtil::stk_util_util" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_util APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_util PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_util.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_util_util.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_util )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_util "${_IMPORT_PREFIX}/lib/libstk_util_util.so.15.1.1" )

# Import target "STKUtil::stk_util_parallel" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_parallel APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_parallel PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_parallel.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_util_parallel.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_parallel )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_parallel "${_IMPORT_PREFIX}/lib/libstk_util_parallel.so.15.1.1" )

# Import target "STKUtil::stk_util_env" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_env APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_env PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_env.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_util_env.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_env )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_env "${_IMPORT_PREFIX}/lib/libstk_util_env.so.15.1.1" )

# Import target "STKUtil::stk_util_registry" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_registry APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_registry PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_registry.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_util_registry.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_registry )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_registry "${_IMPORT_PREFIX}/lib/libstk_util_registry.so.15.1.1" )

# Import target "STKUtil::stk_util_diag" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_diag APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_diag PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_diag.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_util_diag.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_diag )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_diag "${_IMPORT_PREFIX}/lib/libstk_util_diag.so.15.1.1" )

# Import target "STKUtil::stk_util_command_line" for configuration "RELEASE"
set_property(TARGET STKUtil::stk_util_command_line APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(STKUtil::stk_util_command_line PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libstk_util_command_line.so.15.1.1"
  IMPORTED_SONAME_RELEASE "libstk_util_command_line.so.15"
  )

list(APPEND _cmake_import_check_targets STKUtil::stk_util_command_line )
list(APPEND _cmake_import_check_files_for_STKUtil::stk_util_command_line "${_IMPORT_PREFIX}/lib/libstk_util_command_line.so.15.1.1" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
